@@ -4,7 +4,7 @@ use 5.006;
 use strict;
 use warnings;
 
-our $VERSION = '0.002';
+our $VERSION = '0.003';
 require Exporter;
 our @ISA = qw(Exporter);
 our @EXPORT    = qw(to_human_string);
@@ -160,11 +160,6 @@ C<to_human_string()>, to save on typing.
 
 Zoffix Znet, C<< <zoffix at cpan.org> >>
 
-=head1 GIT
-
-This module is on GitHub:
-L<https://github.com/zoffixznet/List-ToHumanString.git>
-
 =head1 BUGS
 
 Please report any bugs or feature requests to C<bug-list-tohumanstring at rt.cpan.org>, or through
